global_selection

Function global_selection 

pub fn global_selection() -> SharedTextSelection
Get the global text selection state

This is a singleton that persists for the lifetime of the application. Use this to check what text is currently selected for clipboard operations.