pub fn motion() -> MotionExpand description
Create a motion container
The motion container automatically generates a stable unique key using UUID, ensuring uniqueness even when created in loops or closures.
For additional uniqueness in loops, use .id():
ⓘ
for i in 0..items.len() {
motion()
.id(i) // Appends index to auto-generated key
.fade_in(300)
.child(item_content)
}